
# Type: has percentage


equivalent to has quotient multiplied by 100

URI: [biolink:has_percentage](https://w3id.org/biolink/vocab/has_percentage)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Double](types/Double.md)

## Parents

 *  is_a: [aggregate statistic](aggregate_statistic.md)

## Children


## Used by

 * [FrequencyQuantifier](FrequencyQuantifier.md)
 * [VariantToPopulationAssociation](VariantToPopulationAssociation.md)
